
    
import copy
from test.test_init.kraken_testfn.helpers import json
import os
import pkg_resources

"""
Notes:
To access files in data directory, use:
new_path = pkg_resources.resource_filename('kraken_testfn', old_path)

"""

        
def method1():
    """
    """
    
    return True


def method2():
    """
    """
    
    return True



        

    